@@ -146,7 +146,7 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
         help_message = (
             "You can specify a package in the following forms:\n"
             "  - A single name (<b>requests</b>)\n"
-            "  - A name and a constraint (<b>requests ^2.23.0</b>)\n"
+            "  - A name and a constraint (<b>requests@^2.23.0</b>)\n"
             "  - A git url (<b>git+https://github.com/python-poetry/poetry.git</b>)\n"
             "  - A git url with a revision (<b>git+https://github.com/python-poetry/poetry.git#develop</b>)\n"
             "  - A file path (<b>../my-package/my-package.whl</b>)\n"
