@@ -44,6 +44,7 @@ class Builder(object):
         self._io = io
         self._package = poetry.package
         self._path = poetry.file.parent
+        self._original_path = self._path
 
         packages = []
         for p in self._package.packages:
@@ -75,7 +76,7 @@ class Builder(object):
     @lru_cache(maxsize=None)
     def find_excluded_files(self):  # type: () -> Set[str]
         # Checking VCS
-        vcs = get_vcs(self._path)
+        vcs = get_vcs(self._original_path)
         if not vcs:
             vcs_ignored_files = set()
         else:
